var classPMPSelfIntersectionTraits =
[
    [ "Construct_segment_3", "classPMPSelfIntersectionTraits.html#ae490aafcda8ed998759842a67a57ca92", null ],
    [ "Construct_triangle_3", "classPMPSelfIntersectionTraits.html#a841af4ea980b4130a4fa477633bc4dcf", null ],
    [ "Do_intersect_3", "classPMPSelfIntersectionTraits.html#a0cd254de374b3b52dfa55268c99de276", null ],
    [ "Point_3", "classPMPSelfIntersectionTraits.html#adbd168594bb0dda280073cd886bcae5e", null ],
    [ "Segment_3", "classPMPSelfIntersectionTraits.html#a66f3a6d91df8b9708695119b8d588003", null ],
    [ "Triangle_3", "classPMPSelfIntersectionTraits.html#aec3c2d71b0d0197f7b991cf45954a6c5", null ]
];